// Copyright (c) 2016, Google Inc. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.

import 'dart:async';

import 'package:build/build.dart';
import 'package:sass/sass.dart' as sass;

/// Defines a builder from creating `.css` files from `.scss`.
class SassBuilder implements Builder {
  const SassBuilder();

  @override
  Future<Null> build(BuildStep buildStep) async {
    assert(() {
      if (buildStep.input.id.extension != '.scss') {
        throw new StateError('Unexpected file: ${buildStep.input.id}.');
      }
      return true;
    });
    buildStep.writeAsString(
      new Asset(
        buildStep.input.id.changeExtension('.scss.css'),
        sass.render(buildStep.input.id.path),
      ),
    );
  }

  @override
  List<AssetId> declareOutputs(AssetId inputId) {
    if (inputId.extension == '.scss') {
      return [inputId.changeExtension('.scss.css')];
    }
    return const [];
  }
}
